/*
 * gc global variable provides access to GUI Composer infrastructure components and project information.
 * For more information, please see the Working with Javascript guide in the online help.
 */
var gc = gc || {};
gc.services = gc.services || {};

/*
 *  Boilerplate code for creating computed data bindings
 */
document.addEventListener('gc-databind-ready', function() {
    /*
     *   Add custom computed value databindings here, using the following method:
     *
     *   function gc.databind.registry.bind(targetBinding, modelBinding, [getter], [setter]);
     *
     *   param targetBinding - single binding string or expression, or array of binding strings for multi-way binding.
     *   param modelBinding - single binding string or expression, or array of binding strings for multi-way binding.
     *   param getter - (optional) - custom getter function for computing the targetBinding value(s) based on modelBinding value(s).
     *   param setter - (optional) - custom setter function for computing the modelBinding value(s) based on targetBinding value(s).
     */

    // For example, a simple computed values based on simple expression
    // gc.databind.registry.bind('widget.id.propertyName', "targetVariable == 1 ? 'binding is one' : 'binding is not one'");

    // Or a custom two-way binding with custome getter and setter functions.  (setter is optional)  (getter only indicates one-way binding)
    // gc.databind.registry.bind('widget.id.propertyName', "targetVariable", function(value) { return value*5/9 + 32; }, function(value) { (return value-32)*9/5; });

    // Event 1 to n bindings
    /*
    gc.databind.registry.bind('widget.date.value',
        // dependant bindings needed in order to compute the date, in name/value pairs.
        {
            weekday: 'widget.dayOfWeek.selectedText',
            day: 'widget.dayOfMonth.value',
            month: 'widget.month.selectedText',
            year: 'widget.year.value'
        },
        // getter for date computation
        function(values)
        {
            // compute and return the string value to bind to the widget with id 'date'
            return values.weekday + ', ' + values.month + ' ' + values.day + ', ' + values.year;
        }
    );
	*/
});

/*
 *  Boilerplate code for creating custom actions
 */
document.addEventListener('gc-nav-ready', function() {
    /*
     *   Add custom actions for menu items using the following api:
     *
     *   function gc.nav.registryAction(id, runable, [isAvailable], [isVisible]);
     *
     *   param id - uniquely identifies the action, and should correspond to the action property of the menuaction widget.
     *   param runable - function that performs the custom action.
     *   param isAvailable - (optional) - function called when the menu action is about to appear.  Return false to disable the action, or true to enable it.
     *   param isVisible - (optional) - function called when the menu action is about to appear.  Return false to hide the action, or true to make it visible.
     */

    // For example,
    // gc.nav.registerAction('myCustomCloseAction', function() { window.close(); }, function() { return true; }, function() { return true; });

    // Alternatively, to programmatically disable a menu action at any time use:
    // gc.nav.disableAction('myCustomCloseAction);    then enable it again using:  gc.nav.enableAction('myCustomCloseAction');

    gc.nav.registerAction('open_log_pane', function() {
        if ((templateObj) && (templateObj.$)) {
            templateObj.$.ti_widget_eventlog_view.openView();
        }
    }, function() {
        return true;
    }, function() {
        return true;
    });

    gc.nav.registerAction('open_scripting_window', function() {
        window.open('app/scripting.html', '_oob_scripting');
    }, function() {
        return true;
    }, function() {
        return true;
    });
});


var initComplete = false;
var templateObj;
var PWM1Changed;
var PWM2Changed;
var PWM3Changed;

// global variables for Plot 1
var dacDataArray = [];
var dacPlotObj;
var dacPlotOptions;
var updateDAC;
var signalFreq;
var signalAmp; 
var dacFreq;
var sampleLen;
var opAmpMode;
var dcBias;
var dutyCycle;

// global variables for Plot 2
var dacDataArray1 = [];
var dacPlotObj1;
var dacPlotOptions1;
var updateDAC1;
var signalFreq1;
var signalAmp1; 
var dacFreq1;
var sampleLen1;
var opAmpMode1;
var dcBias1;
var dutyCycle1;

// global variables for Plot 3
var dacDataArray2 = [];
var dacPlotObj2;
var dacPlotOptions2;
var updateDAC2;
var signalFreq2;
var signalAmp2; 
var dacFreq2;
var sampleLen2;
var opAmpMode2;
var dcBias2;
var dutyCycle2;

/*
 *  Boilerplate code for working with components in the application gist
 */

// Wait for DOMContentLoaded event before trying to access the application template
var init = function() {
    templateObj = document.querySelector('#template_obj');

    // Wait for the template to fire a dom-change event to indicate that it has been 'stamped'
    // before trying to access components in the application.
	templateObj.addEventListener('dom-change',function(){
	    if (initComplete) return;
	    this.async(function(){
            initComplete = true;

            // Expand vtabcontainer nav bar when user clicks on menu icon or 'Menu' label
            templateObj.toggleMenu = function(event){
                templateObj.$.ti_widget_vtabcontainer.isExpanded = !templateObj.$.ti_widget_vtabcontainer.isExpanded;
            };
            templateObj.$.ti_widget_icon_button_menu.addEventListener('click',templateObj.toggleMenu);
            templateObj.$.ti_widget_label_menu.addEventListener('click',templateObj.toggleMenu);

            // learn more & show less labels
            if (templateObj.$.ti_widget_label_learnmore) {
                templateObj.$.ti_widget_label_learnmore.addEventListener("click", function (event) {
                    templateObj.$.ti_widget_label_productname.fontColor = "#444";
                    templateObj.$.ti_widget_label_productdesc.fontColor = "#444";
                    templateObj.$.ti_widget_label_learnmore.setAttribute('hidden', true);
                    templateObj.$.ti_widget_label_showless.removeAttribute('hidden');
                    templateObj.$.ti_widget_vtab_home.style.backgroundColor = "white";
                    templateObj.$.ti_widget_tabcontainer.selectedIndex = 1;
                });
            }
            if (templateObj.$.ti_widget_label_showless) {
                templateObj.$.ti_widget_label_showless.addEventListener("click", function (event) {
                    templateObj.$.ti_widget_label_productname.fontColor = "white";
                    templateObj.$.ti_widget_label_productdesc.fontColor = "white";
                    templateObj.$.ti_widget_label_learnmore.removeAttribute('hidden');
                    templateObj.$.ti_widget_label_showless.setAttribute('hidden', true);
                    templateObj.$.ti_widget_vtab_home.style.backgroundColor = "rgb(20, 140, 156)";
                    templateObj.$.ti_widget_tabcontainer.selectedIndex = 0;
                });
            }
            if (templateObj.$.ti_widget_button_connect) {
                templateObj.$.ti_widget_button_connect.addEventListener("click", function(event){
                    if (gc.connectionManager){
                        gc.connectionManager.connect();
                    }
                });
            }

    	    console.log("Application template has been stamped.");
  	        // Now that the template has been stamped, you can use 'automatic node finding' $ syntax to access widgets.
  	        // e.g. to access a widget with an id of 'widget_id' you can use templateObj.$.widgetId
            
            
              	          	        // Override default Software Manifest
            var aboutBox = document.querySelector('ti-widget-aboutbox');    
            aboutBox.addEventListener("aboutbox_opening", function(event){
                aboutBox.softwareManifestLink = "app/docs/MSP-EXP430FR2355LaunchPadOOBDemoGUI_manifest.html";
            }); // TODO
            var navigatejs = document.createElement("script");
            window.navigatejs = navigatejs;
            navigatejs.type = "text/javascript";
            navigatejs.src = "app/js/jquery.flot.navigate.js";
            
            navigatejs.onload = function() {
                
                //$("#ti_widget_scalargraph_dac").find("#xAxisLabel").html("Samples per second");
                // added---------------
                //$("#ti_widget_scalargraph_dac1").find("#xAxisLabel").html("Samples per second");
                //$("#ti_widget_scalargraph_dac2").find("#xAxisLabel").html("Samples per second");

                // --------------------   

      	        updateDAC = function () {
      	            PWM1Changed = 0; // reset PWM changed
      	            dacDataArray = [];
      	            
      	            signalFreq = (templateObj.$.ti_widget_droplist_freq.selectedIndex + 1) * 5; // TODO: need to fix scale for frequency, it is too packed for 500 Hz
      	            signalAmp = 1.65; 
      	            dacFreq = 30000; // set to highest DAC
      	            sampleLen = dacFreq / signalFreq * 5;
      	            opAmpMode = 0; // always set to 0
      	            dcBias = (opAmpMode === 0) ? 1.65 : signalAmp;
      	            dutyCycle = (templateObj.$.ti_widget_droplist_dutycycle.selectedIndex + 1) * 10 / 100; // in decimal value
      	            
      	            // display graph using duty cycles on plot
                    for (i = 0; i < sampleLen * dutyCycle; i++) {   // 'on' time 
                        dacDataArray.push([i, dcBias + signalAmp]);
                    }
                    for (i = sampleLen * dutyCycle; i < sampleLen; i++) { // 'off' time
                        dacDataArray.push([i, dcBias - signalAmp]);
                    }
                    
                    while(dacDataArray.length < dacFreq) {
                        for (j = 0; j < sampleLen; j++)
                            dacDataArray.push([dacDataArray.length, dacDataArray[j][1]]);
                    }
                    dacDataArray.push([dacDataArray.length, dacDataArray[dacDataArray.length-1][1]]);
                    
                    dacPlotOptions = {
                        series: {
                            lines: {show: true, steps: true}
                            // points: {show: true}
                        },
                        xaxis: {
                            min: 0,
                            max: dacFreq,
                            zoomRange:[0.1, dacFreq],
                            panRange:[0, dacFreq]
                        },
                        yaxis: {
                            max: 3.5,
                            min: 0,
                            zoomRange:[0.1, 3.5],
                            panRange:[0, 3.5]
                            // tickFormatter: function (val, axis) {
                            //     if (val >= 3.0)
                            //         return val + " V";
                            //     else
                            //         return val + '&nbsp;&nbsp;&nbsp;';
                            // }
                        },
                        colors: ["#00bbcc"],
                        grid: {
                            hoverable: true,
                            autoHighlight: true
                        },
                        zoom: {
                            interactive: true
                        },
                        pan: {
                            interactive: true
                        }
                    };
                    dacPlotObj = $.plot(templateObj.$.ti_widget_scalargraph_dac.querySelector("#chart"), [ dacDataArray ], dacPlotOptions);
      	        };
      	        
      	        // added---------------
      	        updateDAC1 = function () {
      	            PWM2Changed = 0; // reset PWM changed
      	            dacDataArray1 = [];
      	            
      	            signalFreq1 = (templateObj.$.ti_widget_droplist_freq1.selectedIndex + 1) * 5; // TODO: need to fix scale for frequency, it is too packed for 500 Hz
      	            signalAmp1 = 1.65; 
      	            dacFreq1 = 30000; // set to highest DAC
      	            sampleLen1 = dacFreq1 / signalFreq1 * 5;
      	            opAmpMode1 = 0; // always set to 0
      	            dcBias1 = (opAmpMode1 === 0) ? 1.65 : signalAmp1;
      	            dutyCycle1 = (templateObj.$.ti_widget_droplist_dutycycle1.selectedIndex + 1) * 10 / 100; // in decimal value
      	            
      	            // display graph using duty cycles on plot
                    for (i = 0; i < sampleLen1 * dutyCycle1; i++) {   // 'on' time 
                        dacDataArray1.push([i, dcBias1 + signalAmp1]);
                    }
                    for (i = sampleLen1 * dutyCycle1; i < sampleLen1; i++) { // 'off' time
                        dacDataArray1.push([i, dcBias1 - signalAmp1]);
                    }
                    
                    while(dacDataArray1.length < dacFreq1) {
                        for (j = 0; j < sampleLen1; j++)
                            dacDataArray1.push([dacDataArray1.length, dacDataArray1[j][1]]);
                    }
                    dacDataArray1.push([dacDataArray1.length, dacDataArray1[dacDataArray1.length-1][1]]);
                    
                    dacPlotOptions1 = {
                        series: {
                            lines: {show: true, steps: true}
                            // points: {show: true}
                        },
                        xaxis: {
                            min: 0,
                            max: dacFreq1,
                            zoomRange:[0.1, dacFreq1],
                            panRange:[0, dacFreq1]
                        },
                        yaxis: {
                            max: 3.5,
                            min: 0,
                            zoomRange:[0.1, 3.5],
                            panRange:[0, 3.5]
                            // tickFormatter: function (val, axis) {
                            //     if (val >= 3.0)
                            //         return val + " V";
                            //     else
                            //         return val + '&nbsp;&nbsp;&nbsp;';
                            // }
                        },
                        colors: ["#00bbcc"],
                        grid: {
                            hoverable: true,
                            autoHighlight: true
                        },
                        zoom: {
                            interactive: true
                        },
                        pan: {
                            interactive: true
                        }
                    };
                    dacPlotObj1 = $.plot(templateObj.$.ti_widget_scalargraph_dac1.querySelector("#chart"), [ dacDataArray1 ], dacPlotOptions1);
      	        };
      	        
      	        updateDAC2 = function () {
      	            PWM3Changed = 0; // reset PWM changed
      	            dacDataArray2 = [];
      	            
      	            signalFreq2 = (templateObj.$.ti_widget_droplist_freq2.selectedIndex + 1) * 5; // TODO: need to fix scale for frequency, it is too packed for 500 Hz
      	            signalAmp2 = 1.65; 
      	            dacFreq2 = 30000; // set to highest DAC
      	            sampleLen2 = dacFreq2 / signalFreq2 * 5;
      	            opAmpMode2 = 0; // always set to 0
      	            dcBias2 = (opAmpMode2 === 0) ? 1.65 : signalAmp2;
      	            dutyCycle2 = (templateObj.$.ti_widget_droplist_dutycycle2.selectedIndex + 1) * 10 / 100; // in decimal value
      	            
      	            // display graph using duty cycles on plot
                    for (i = 0; i < sampleLen2 * dutyCycle2; i++) {   // 'on' time 
                        dacDataArray2.push([i, dcBias2 + signalAmp2]);
                    }
                    for (i = sampleLen2 * dutyCycle2; i < sampleLen2; i++) { // 'off' time
                        dacDataArray2.push([i, dcBias2 - signalAmp2]);
                    }
                    
                    while(dacDataArray2.length < dacFreq2) {
                        for (j = 0; j < sampleLen2; j++)
                            dacDataArray2.push([dacDataArray2.length, dacDataArray2[j][1]]);
                    }
                    dacDataArray2.push([dacDataArray2.length, dacDataArray2[dacDataArray2.length-1][1]]);
                    
                    dacPlotOptions2 = {
                        series: {
                            lines: {show: true, steps: true}
                            // points: {show: true}
                        },
                        xaxis: {
                            min: 0,
                            max: dacFreq2,
                            zoomRange:[0.1, dacFreq2],
                            panRange:[0, dacFreq2]
                        },
                        yaxis: {
                            max: 3.5,
                            min: 0,
                            zoomRange:[0.1, 3.5],
                            panRange:[0, 3.5]
                            // tickFormatter: function (val, axis) {
                            //     if (val >= 3.0)
                            //         return val + " V";
                            //     else
                            //         return val + '&nbsp;&nbsp;&nbsp;';
                            // }
                        },
                        colors: ["#00bbcc"],
                        grid: {
                            hoverable: true,
                            autoHighlight: true
                        },
                        zoom: {
                            interactive: true
                        },
                        pan: {
                            interactive: true
                        }
                    };
                    dacPlotObj2 = $.plot(templateObj.$.ti_widget_scalargraph_dac2.querySelector("#chart"), [ dacDataArray2 ], dacPlotOptions2);
      	        };
      	        
      	         clearDAC = function () {
      	            PWM1Changed = 0; // reset PWM changed
      	            dacDataArray = [];
      	                 	            
      	            signalAmp = 1.65; 
      	            dacFreq = 30000; // set to highest DAC
      	            sampleLen = dacFreq / signalFreq * 5;
      	            opAmpMode = 0; // always set to 0
      	            dcBias = (opAmpMode === 0) ? 1.65 : signalAmp;

      	            // display graph using duty cycles on plot
                    for (i = 0; i < sampleLen * dutyCycle; i++) {   // 'on' time 
                        dacDataArray.push([i, dcBias + signalAmp]);
                    }
                    for (i = sampleLen * dutyCycle; i < sampleLen; i++) { // 'off' time
                        dacDataArray.push([i, dcBias - signalAmp]);
                    }
                    
                    while(dacDataArray.length < dacFreq) {
                        for (j = 0; j < sampleLen; j++)
                            dacDataArray.push([dacDataArray.length, dacDataArray[j][1]]);
                    }
                    dacDataArray.push([dacDataArray.length, dacDataArray[dacDataArray.length-1][1]]);
                    
                    dacPlotOptions = {
                        series: {
                            lines: {show: true, steps: true}
                            // points: {show: true}
                        },
                        xaxis: {
                            min: 0,
                            max: dacFreq,
                            zoomRange:[0.1, dacFreq],
                            panRange:[0, dacFreq]
                        },
                        yaxis: {
                            max: 3.5,
                            min: 0,
                            zoomRange:[0.1, 3.5],
                            panRange:[0, 3.5]
                            // tickFormatter: function (val, axis) {
                            //     if (val >= 3.0)
                            //         return val + " V";
                            //     else
                            //         return val + '&nbsp;&nbsp;&nbsp;';
                            // }
                        },
                        colors: ["#00bbcc"],
                        grid: {
                            hoverable: true,
                            autoHighlight: true
                        },
                        zoom: {
                            interactive: true
                        },
                        pan: {
                            interactive: true
                        }
                    };
                    dacPlotObj = $.plot(templateObj.$.ti_widget_scalargraph_dac.querySelector("#chart"), [ dacDataArray ], dacPlotOptions);
      	        };
      	        
      	        clearDAC1 = function () {
      	            PWM2Changed = 0; // reset PWM changed
      	            dacDataArray1 = [];
      	                 	            
      	            signalAmp1 = 1.65; 
      	            dacFreq1 = 30000; // set to highest DAC
      	            sampleLen1 = dacFreq2 / signalFreq2 * 5;
      	            opAmpMode1 = 0; // always set to 0
      	            dcBias1 = (opAmpMode1 === 0) ? 1.65 : signalAmp1;

      	            // display graph using duty cycles on plot
                    for (i = 0; i < sampleLen1 * dutyCycle1; i++) {   // 'on' time 
                        dacDataArray1.push([i, dcBias1 + signalAmp1]);
                    }
                    for (i = sampleLen1 * dutyCycle1; i < sampleLen1; i++) { // 'off' time
                        dacDataArray1.push([i, dcBias1 - signalAmp1]);
                    }
                    
                    while(dacDataArray1.length < dacFreq1) {
                        for (j = 0; j < sampleLen1; j++)
                            dacDataArray1.push([dacDataArray1.length, dacDataArray1[j][1]]);
                    }
                    dacDataArray1.push([dacDataArray1.length, dacDataArray1[dacDataArray1.length-1][1]]);
                    
                    dacPlotOptions1 = {
                        series: {
                            lines: {show: true, steps: true}
                            // points: {show: true}
                        },
                        xaxis: {
                            min: 0,
                            max: dacFreq1,
                            zoomRange:[0.1, dacFreq1],
                            panRange:[0, dacFreq1]
                        },
                        yaxis: {
                            max: 3.5,
                            min: 0,
                            zoomRange:[0.1, 3.5],
                            panRange:[0, 3.5]
                            // tickFormatter: function (val, axis) {
                            //     if (val >= 3.0)
                            //         return val + " V";
                            //     else
                            //         return val + '&nbsp;&nbsp;&nbsp;';
                            // }
                        },
                        colors: ["#00bbcc"],
                        grid: {
                            hoverable: true,
                            autoHighlight: true
                        },
                        zoom: {
                            interactive: true
                        },
                        pan: {
                            interactive: true
                        }
                    };
                    dacPlotObj1 = $.plot(templateObj.$.ti_widget_scalargraph_dac1.querySelector("#chart"), [ dacDataArray1 ], dacPlotOptions1);
      	        };
      	        
      	        clearDAC2 = function () {
      	            PWM3Changed = 0; // reset PWM changed
      	            dacDataArray2 = [];
      	            templateObj.$.ti_widget_led2.on = true;

      	                 	            
      	            signalAmp2 = 1.65; 
      	            dacFreq2 = 30000; // set to highest DAC
      	            sampleLen2 = dacFreq2 / signalFreq2 * 5;
      	            opAmpMode2 = 0; // always set to 0
      	            dcBias2 = (opAmpMode2 === 0) ? 1.65 : signalAmp2;

      	            // display graph using duty cycles on plot
                    for (i = 0; i < sampleLen2 * dutyCycle2; i++) {   // 'on' time 
                        dacDataArray2.push([i, dcBias2 + signalAmp2]);
                    }
                    for (i = sampleLen2 * dutyCycle2; i < sampleLen2; i++) { // 'off' time
                        dacDataArray2.push([i, dcBias2 - signalAmp2]);
                    }
                    
                    while(dacDataArray2.length < dacFreq2) {
                        for (j = 0; j < sampleLen2; j++)
                            dacDataArray2.push([dacDataArray2.length, dacDataArray2[j][1]]);
                    }
                    dacDataArray2.push([dacDataArray2.length, dacDataArray2[dacDataArray2.length-1][1]]);
                    
                    dacPlotOptions2 = {
                        series: {
                            lines: {show: true, steps: true}
                            // points: {show: true}
                        },
                        xaxis: {
                            min: 0,
                            max: dacFreq2,
                            zoomRange:[0.1, dacFreq2],
                            panRange:[0, dacFreq2]
                        },
                        yaxis: {
                            max: 3.5,
                            min: 0,
                            zoomRange:[0.1, 3.5],
                            panRange:[0, 3.5]
                            // tickFormatter: function (val, axis) {
                            //     if (val >= 3.0)
                            //         return val + " V";
                            //     else
                            //         return val + '&nbsp;&nbsp;&nbsp;';
                            // }
                        },
                        colors: ["#00bbcc"],
                        grid: {
                            hoverable: true,
                            autoHighlight: true
                        },
                        zoom: {
                            interactive: true
                        },
                        pan: {
                            interactive: true
                        }
                    };
                    dacPlotObj2 = $.plot(templateObj.$.ti_widget_scalargraph_dac2.querySelector("#chart"), [ dacDataArray2 ], dacPlotOptions2);
      	        };
      	        
      	        
      	        // --------------------
                
            	$("<div id='datatag'></div>").css({
            		position: "absolute",
            		display: "none",
            		border: "1px solid #fdd",
            		padding: "2px",
            		"background-color": "#fee",
            		opacity: 0.80
            	}).appendTo("body");
        		
        		$("#ti_widget_scalargraph_dac").find("#chart").bind("plothover", function (event, pos, item) {
    				if (item) {
    					var x = item.datapoint[0],
    						y = item.datapoint[1].toFixed(2);
    
    					$("#datatag").html("(" + x + ", " + y + ")")
    						.css({top: item.pageY+5, left: item.pageX+5})
    						.fadeIn(200);
    				} else {
    					$("#datatag").hide();
    				}
        		});
        		

        	    $("<div id='datatag1'></div>").css({
            		position: "absolute",
            		display: "none",
            		border: "1px solid #fdd",
            		padding: "2px",
            		"background-color": "#fee",
            		opacity: 0.80
            	}).appendTo("body");
            	
        		$("#ti_widget_scalargraph_dac1").find("#chart").bind("plothover", function (event, pos, item) {
    				if (item) {
    					var x = item.datapoint[0],
    						y = item.datapoint[1].toFixed(2);
    
    					$("#datatag1").html("(" + x + ", " + y + ")")
    						.css({top: item.pageY+5, left: item.pageX+5})
    						.fadeIn(200);
    				} else {
    					$("#datatag1").hide();
    				}
        		});
        		
        		$("<div id='datatag2'></div>").css({
            		position: "absolute",
            		display: "none",
            		border: "1px solid #fdd",
            		padding: "2px",
            		"background-color": "#fee",
            		opacity: 0.80
            	}).appendTo("body");
            	
        		$("#ti_widget_scalargraph_dac2").find("#chart").bind("plothover", function (event, pos, item) {
    				if (item) {
    					var x = item.datapoint[0],
    						y = item.datapoint[1].toFixed(2);
    
    					$("#datatag2").html("(" + x + ", " + y + ")")
    						.css({top: item.pageY+5, left: item.pageX+5})
    						.fadeIn(200);
    				} else {
    					$("#datatag2").hide();
    				}
        		});

        		updateDAC();
        		updateDAC1();
        		updateDAC2();
        		
        		// change timer
        		templateObj.$.ti_widget_droplist_timer.addEventListener('selected-index-changed', () => {                    
                    //updateDAC();
                    PWM1Changed = 0; //TODO: double check this
                    PWM2Changed = 0; //TODO: double check this
                    PWM3Changed = 0; //TODO: double check this

                    // global variables for Plot 3
                    signalFreq = 10; // default value
                    signalFreq1 = 10; // default value
                    signalFreq2 = 10; // default value
                    dutyCycle = 0.2; // default value
                    dutyCycle1 = 0.2; // default value
                    dutyCycle2 = 0.2; // default value
                    clearDAC();
                    clearDAC1();
                    clearDAC2();
                    ti_widget_droplist_freq.selectedIndex = 1;
                    ti_widget_droplist_freq1.selectedIndex = 1;
                    ti_widget_droplist_freq2.selectedIndex = 1;
                    ti_widget_droplist_dutycycle.selectedIndex = 1;
                    ti_widget_droplist_dutycycle1.selectedIndex = 1;
                    ti_widget_droplist_dutycycle2.selectedIndex = 1;
                    ti_widget_droplist_ccr.selectedIndex = 0;
                    ti_widget_droplist_ccr1.selectedIndex = 0;
                    ti_widget_droplist_ccr2.selectedIndex = 0;
                    templateObj.$.ti_widget_led.on = true;                // PWM2
                    templateObj.$.ti_widget_led1.on = true;                // PWM2
                    templateObj.$.ti_widget_led2.on = true;                // PWM2



        		});
                
                templateObj.$.ti_widget_droplist_ccr2.addEventListener('selected-index-changed', () => {                    
                    ti_widget_droplist_freq2.selectedIndex = 1;
                    ti_widget_droplist_dutycycle2.selectedIndex = 1;
                });
                    
                // frequency changed through drop list
                // PWM1
                templateObj.$.ti_widget_droplist_freq.addEventListener('selected-index-changed', () => {                    
                    //updateDAC();
                    PWM1Changed = 1;
                    signalFreq = (ti_widget_droplist_freq.selectedIndex + 1) * 5;
                    templateObj.$.ti_model_streaming.sendValue({"signalFreq":signalFreq});
                    templateObj.$.ti_widget_led.on = false;                // PWM2
                    
                });
                templateObj.$.ti_widget_droplist_freq1.addEventListener('selected-index-changed', () => {                    
                    //updateDAC1();
                    PWM2Changed = 1;
                    signalFreq1 = (ti_widget_droplist_freq1.selectedIndex + 1) * 5;
                    templateObj.$.ti_model_streaming.sendValue({"signalFreq1":signalFreq1});
                    templateObj.$.ti_widget_led1.on = false;                // PWM2
                });
                // PWM3
                templateObj.$.ti_widget_droplist_freq2.addEventListener('selected-index-changed', () => {                    
                    //updateDAC2();
                    PWM3Changed = 1;
                    signalFreq2 = (ti_widget_droplist_freq2.selectedIndex + 1) * 5;
                    templateObj.$.ti_model_streaming.sendValue({"signalFreq2":signalFreq2});
                    templateObj.$.ti_widget_led2.on = false;                // PWM2
                });

                // duty cycle changed through drop list
                // PWM1
                templateObj.$.ti_widget_droplist_dutycycle.addEventListener('selected-index-changed', () => {                     
                    //updateDAC();
                    PWM1Changed = 1;
                    dutyCycle = (ti_widget_droplist_dutycycle.selectedIndex + 1) * 10 / 100;
                    templateObj.$.ti_model_streaming.sendValue({"dutyCycle":dutyCycle}); 
                    templateObj.$.ti_widget_led.on = false;                // PWM2
                    
                });
                // PWM2
                templateObj.$.ti_widget_droplist_dutycycle1.addEventListener('selected-index-changed', () => {                    
                    //updateDAC1();
                    PWM2Changed = 1;
                    dutyCycle1 = (ti_widget_droplist_dutycycle1.selectedIndex + 1) * 10 / 100;
                    templateObj.$.ti_model_streaming.sendValue({"dutyCycle1":dutyCycle1});
                    templateObj.$.ti_widget_led1.on = false;                // PWM2
                    
                });
                // PWM3   
                templateObj.$.ti_widget_droplist_dutycycle2.addEventListener('selected-index-changed', () => {                    
                    //updateDAC2();
                    PWM3Changed = 1;
                    dutyCycle2 = (ti_widget_droplist_dutycycle2.selectedIndex + 1) * 10 / 100;
                    templateObj.$.ti_model_streaming.sendValue({"dutyCycle2":dutyCycle2});
                    templateObj.$.ti_widget_led2.on = false;                // PWM2
                    
                });
                
                // plot button is pressed
                // PWM1
                templateObj.$.ti_widget_button_plot.addEventListener('click', () => {
                    /* handler code goes here */ 
                    updateDAC();
                    //templateObj.$.ti_widget_led.write = 0; 
                    templateObj.$.ti_widget_led.on = true;
                    
                });
                // PWM2
                templateObj.$.ti_widget_button_plot1.addEventListener('click', () => {
                    /* handler code goes here */ 
                    updateDAC1();
                    templateObj.$.ti_widget_led1.on = true;
                });
                // PWM3
                templateObj.$.ti_widget_button_plot2.addEventListener('click', () => {
                    /* handler code goes here */ 
                    updateDAC2();
                    templateObj.$.ti_widget_led2.on = true;
                });
                
                // CCR changed on plot 3
                templateObj.$.ti_widget_droplist_ccr2.addEventListener('selected-index-changed', () => {                     
                    //updateDAC();
                    PWM1Changed = 0; //TODO: double check this
                    // global variables for Plot 3
                    signalFreq2 = 10; // default value
                    dutyCycle2 = 0.2; // default value
                    clearDAC2();

                });
            
                function updateLaunchPad() {
      	            signalFreq = ti_widget_droplist_freq.selectedIndex;
      	            signalAmp = 1.65;
      	            dacFreq = 8192;
      	            
      	            signalFreq1 = ti_widget_droplist_freq1.selectedIndex;
      	            signalAmp1 = 1.65;
      	            dacFreq1 = 8192;
      	            
      	            signalFreq2 = ti_widget_droplist_freq2.selectedIndex;
      	            signalAmp2 = 1.65;
      	            dacFreq2 = 8192;

                    templateObj.$.ti_model_streaming.sendValue({
                        "signalFreq":signalFreq,
                        "signalAmp":signalAmp,
                        "dacFreq":dacFreq,
                        "dutyCycle":dutyCycle,

                        "signalFreq1":signalFreq1,
                        "signalAmp1":signalAmp1,
                        "dacFreq1":dacFreq1,
                        "dutyCycle1":dutyCycle1,
                        
                        "signalFreq2":signalFreq2,
                        "signalAmp2":signalAmp2,
                        "dacFreq2":dacFreq2,
                        "dutyCycle2":dutyCycle2
                    });
                }
                
                window.addEventListener("resize", function() {
                    console.log("resize event");
                    setTimeout(updateDAC,300);
                    setTimeout(updateDAC1,300);
                    setTimeout(updateDAC2,300);
                    // updateDAC();
                    // dacPlotObj = $.plot(templateObj.$.ti_widget_scalargraph_dac.querySelector("#chart"), [ dacDataArray ], dacPlotOptions);
                });
            };
            
            var navigateJsLoaded = false;
            templateObj.$.ti_widget_vtabcontainer.addEventListener("selected-index-changed",(event)=>{
                if (event.detail.value == 1 && !navigateJsLoaded){
                    document.body.appendChild(navigatejs);
                    navigateJsLoaded = true;
                }
            });
            //setTimeout(()=>document.body.appendChild(navigatejs),1000);
            //document.body.appendChild(navigatejs);
            //document.body1.appendChild(navigatejs);
        },500);

	});
};

templateObj = document.querySelector('#template_obj');
if (templateObj) {
    init();
} else {
    document.addEventListener('DOMContentLoaded',init.bind(this))
}